//
//  OpenPlatforActionViewController.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//

#import "OpenPlatformActionDataControl.h"
#import "OpenPlatformActionView.h"
#import "OpenPlatformActionViewController.h"
#import "OpenPlatformCellProtocol.h"
#import "OpenPlatformSectionCell.h"
#import "OpenPlatformSession.h"
#import "OpenPlatformShareViewController.h"
#import "OpenPlatformUIDefine.h"
#import "DemoNetworkManager.h"
#import "DemoShareSoundNetworkManager.h"
#import "UIAlertController+Addition.h"
#import <TikTokOpenSDK/TikTokOpenSDKAuth.h>
#import <Masonry/Masonry.h>

@interface OpenPlatformActionViewController () <UITableViewDelegate, UITableViewDataSource>

@property (nonatomic, strong) UITableView *appInfoTableView;
@property (nonatomic, strong) OpenPlatformActionDataControl *actionDataControl;
@property (nonatomic, strong) OpenPlatformActionView *actionView;

@end

@implementation OpenPlatformActionViewController

#pragma mark - Life cycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    [self p_setupUI];
    [self p_setupConstraints];
}

#pragma mark - Private

- (void)p_setupUI
{
    self.view.backgroundColor = [UIColor demo_colorWithHex:@"#f5f5f5"];
    self.title = @"Actions";
    [self.view addSubview:self.appInfoTableView];
    [self.view addSubview:self.actionView];
    [self.appInfoTableView reloadData];
}

- (void)p_setupConstraints
{
    [self.appInfoTableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.left.right.equalTo(self.view);
        make.bottom.equalTo(self.actionView.mas_top);
    }];
    [self.actionView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self.view).offset(10);
        make.right.equalTo(self.view).offset(-10);
        make.bottom.equalTo(self.view).offset(-(BOTTOM_SAFEAREA_HEIGHT + 20));
        make.height.equalTo(@(50));
    }];
}

#pragma mark - TableView Delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return self.actionDataControl.sessions[indexPath.section].heightForSession;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section
{
    return .1f;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return 25.f;
}

- (UIView *)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section
{
    return [[UIView alloc] init];
}

- (void)scrollViewDidScroll:(UIScrollView *)scrollView
{
    [self.view endEditing:YES];
}

#pragma mark - TableView DataSource
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    OpenPlatformSession *item = self.actionDataControl.sessions[indexPath.row];
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:NSStringFromClass([OpenPlatformSession class])];
    if ([cell conformsToProtocol:@protocol(OpenPlatformSectionProtocol)]) {
        [((id<OpenPlatformSectionProtocol>)cell) configWithSectionItem:item];
    }

    return cell;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.actionDataControl.sessions.count;
}

#pragma mark - Action

- (void)tapAuth
{
    TikTokOpenSDKAuthRequest *request = [[TikTokOpenSDKAuthRequest alloc] init];
    request.permissions = [NSOrderedSet orderedSetWithObject:@"user.info.basic"];

    __weak typeof(self) ws = self;
    [request sendAuthRequestViewController:self
                                completion:^(TikTokOpenSDKAuthResponse *_Nonnull resp) {
        __strong typeof(ws) sf = ws;
        NSString *alertString = nil;
        if (resp.errCode == 0) {
            alertString = [NSString stringWithFormat:@"Author Code : %@, permission : %@", resp.code, resp.grantedPermissions];
            UIPasteboard *pasteboard = [UIPasteboard generalPasteboard];
            pasteboard.string = resp.code;
        } else {
            alertString = [NSString stringWithFormat:@"Author failed code : %@, msg : %@", @(resp.errCode), resp.errString];
        }
        [DemoNetworkManager authLogin:resp.code];
        [UIAlertController showMsg:alertString inVC:sf];
    }];

}

- (void)tapShare
{
    OpenPlatformShareViewController *vc = [[OpenPlatformShareViewController alloc] init];
    [self.navigationController pushViewController:vc animated:YES];
}

- (void)tapShareSound
{
    [DemoShareSoundNetworkManager startShareSoundProcessOnVC:self];
}

#pragma mark - Getters

- (UITableView *)appInfoTableView
{
    if (!_appInfoTableView) {
        _appInfoTableView = [[UITableView alloc] initWithFrame:self.view.frame
                                                         style:UITableViewStyleGrouped];
        [_appInfoTableView registerClass:[OpenPlatformSectionCell class]
                  forCellReuseIdentifier:@"OpenPlatformSession"];
        _appInfoTableView.dataSource = self;
        _appInfoTableView.delegate = self;
        _appInfoTableView.backgroundColor = YAMBGDefualtColor;
        _appInfoTableView.separatorStyle = UITableViewCellSeparatorStyleNone;
        _appInfoTableView.contentInset = UIEdgeInsetsMake(0, 0, 20, 0);
    }

    return _appInfoTableView;
}

- (OpenPlatformActionView *)actionView
{
    if (!_actionView) {
        _actionView = [[OpenPlatformActionView alloc] initWithNumberOfButtons:3];
        [[_actionView buttonAtIndex:0] setTitle:@"Auth" forState:UIControlStateNormal];
        [[_actionView buttonAtIndex:0] addTarget:self action:@selector(tapAuth) forControlEvents:(UIControlEventTouchUpInside)];
        [[_actionView buttonAtIndex:1] setTitle:@"Share" forState:UIControlStateNormal];
        [[_actionView buttonAtIndex:1] addTarget:self action:@selector(tapShare) forControlEvents:UIControlEventTouchUpInside];
        [[_actionView buttonAtIndex:2] setTitle:@"Share Sound" forState:UIControlStateNormal];
        [[_actionView buttonAtIndex:2] addTarget:self action:@selector(tapShareSound) forControlEvents:UIControlEventTouchUpInside];
    }
    return _actionView;
}

- (OpenPlatformActionDataControl *)actionDataControl
{
    if (!_actionDataControl) {
        _actionDataControl = [[OpenPlatformActionDataControl alloc] init];
    }

    return _actionDataControl;
}

@end
