//
//  OpenPlatformEditSettingCell.m
//  OpenSDKDemo
//
//  Created by Jiny Du on 2018/9/25.
//

#import "OpenPlatformEditSettingCell.h"
#import "UIView+Addition.h"

@interface OpenPlatformEditSettingCell () <UITextFieldDelegate>
@property (nonatomic, strong) UILabel *titleDisplaylabel;
@property (nonatomic, strong) UITextField *textField;
@property (nonatomic, strong) OpenPlatformDataItem *item;

@end

@implementation OpenPlatformEditSettingCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self commonInit];
    }

    return self;
}

- (void)commonInit
{
    self.backgroundColor = [UIColor clearColor];
    self.separatorInset = UIEdgeInsetsMake(0, 20, 0, 0);
    self.titleDisplaylabel = ({
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:14];
        label.numberOfLines = 1;
        label.textColor = [UIColor blackColor];
        [self.contentView addSubview:label];
        label;
    });
    self.textField = ({
        UITextField *field = [[UITextField alloc] init];
        field.delegate = self;
        field.borderStyle = UITextBorderStyleNone;
        field.textAlignment = NSTextAlignmentRight;
        field.font = [UIFont systemFontOfSize:14];
        field.textColor = [UIColor blackColor];
        [self.contentView addSubview:field];
        field;
    });
}

- (void)configWithSettingItem:(OpenPlatformDataItem *)item
{
    if (item.type != OpenPlatformItemTypeEdit) {
        return;
    }

    self.item = item;
    self.titleDisplaylabel.text = item.titleString;
    self.textField.placeholder = item.placeholder?:@"";
    self.textField.text = item.editText;

    [self setNeedsLayout];
    [self layoutIfNeeded];
}

- (void)layoutSubviews
{
    [super layoutSubviews];
    [self.titleDisplaylabel sizeToFit];

    self.titleDisplaylabel.frame = CGRectMake(8, (self.contentView.frame.size.height - self.titleDisplaylabel.frame.size.height)/2, self.titleDisplaylabel.frame.size.width, self.titleDisplaylabel.frame.size.height);
    CGFloat currentMaxX = self.titleDisplaylabel.frame.size.width + self.titleDisplaylabel.frame.origin.x;
    self.textField.frame = CGRectMake(currentMaxX + 5.f, 0, self.contentView.frame.size.width - currentMaxX - 5.f - 8.f, self.contentView.frame.size.height);
}

#pragma mark - UITextField Delegate
- (void)textFieldDidEndEditing:(UITextField *)textField
{
    self.item.editText = textField.text;
    !self.item.eventHandler?:self.item.eventHandler(self.item);
}

@end