//
//  OpenPlatformTapEditTableViewCell.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//
#import "OpenPlatformTapEditTableViewCell.h"
#import "UIView+Addition.h"

@interface OpenPlatformTapEditTableViewCell () <UITextFieldDelegate>

@property (nonatomic, strong) UILabel *titleDisplaylabel;
@property (nonatomic, strong) UITextField *textField;
@property (nonatomic, strong) OpenPlatformDataItem *item;
@property (nonatomic, strong) UIButton *button;

@end

@implementation OpenPlatformTapEditTableViewCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self commonInit];
    }

    return self;
}

- (void)commonInit
{
    self.backgroundColor = [UIColor clearColor];
    self.separatorInset = UIEdgeInsetsMake(0, 20, 0, 0);
    self.titleDisplaylabel = ({
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:14];
        label.numberOfLines = 1;
        label.textColor = [UIColor blackColor];
        [self.contentView addSubview:label];
        label;
    });

    self.button = ({
        UIButton *btn = [UIButton buttonWithType:UIButtonTypeSystem];
        btn.frame = CGRectMake(0, 0, 60, 30);
        [btn setTitle:self.item.rightButtonTitle forState:UIControlStateNormal];
        [btn addTarget:self action:@selector(tapRightBtn) forControlEvents:UIControlEventTouchUpInside];

        btn;
    });
    self.textField = ({
        UITextField *field = [[UITextField alloc] init];
        field.delegate = self;
        field.borderStyle = UITextBorderStyleNone;
        field.textAlignment = NSTextAlignmentRight;
        field.font = [UIFont systemFontOfSize:14];
        field.textColor = [UIColor blackColor];
        field.rightView = self.button;
        field.rightViewMode = UITextFieldViewModeAlways;
        [self.contentView addSubview:field];
        field;
    });
}

- (void)tapRightBtn
{
    !self.item.tapRightButtonHandler?:self.item.tapRightButtonHandler(self.item);
    [self setNeedsLayout];
}

- (void)configWithSettingItem:(OpenPlatformDataItem *)item
{
    if (item.type != OpenPlatformItemTypeTapEdit) {
        return;
    }

    self.item = item;
    self.titleDisplaylabel.text = item.titleString;
    [self.button setTitle:item.rightButtonTitle forState:UIControlStateNormal];

    self.textField.placeholder = item.placeholder?:@"";
    self.textField.text = item.editText;

    [self setNeedsLayout];
    [self layoutIfNeeded];
}

- (void)layoutSubviews
{
    [super layoutSubviews];
    [self.titleDisplaylabel sizeToFit];

    self.titleDisplaylabel.frame = CGRectMake(8, (self.contentView.frame.size.height - self.titleDisplaylabel.frame.size.height)/2, self.titleDisplaylabel.frame.size.width, self.titleDisplaylabel.frame.size.height);
    CGFloat currentMaxX = self.titleDisplaylabel.frame.size.width + self.titleDisplaylabel.frame.origin.x;
    self.textField.frame = CGRectMake(currentMaxX + 5.f, 0, self.contentView.frame.size.width - currentMaxX - 5.f - 8.f, self.contentView.frame.size.height);
}

#pragma mark - UITextField Delegate
- (void)textFieldDidEndEditing:(UITextField *)textField
{
    self.item.editText = textField.text;
    !self.item.eventHandler?:self.item.eventHandler(self.item);
}

@end