//
//  DemoNetworkManager.m
//  OpenSDKDemo
//
//  Created by Jiny.du on 2019/7/10.
//  Copyright © 2019 bytedance.co. All rights reserved.
//
#import "DemoNetworkManager.h"
#import "DemoAppConfig.h"

@implementation DemoNetworkManager

+ (NSString *)networkDomain
{
    return @"https://open-api.tiktok.com";
}

+ (BOOL)authLogin:(NSString *)code
{
    return [self authLogin:code completion:nil];
}

+ (BOOL)authLogin:(NSString *)code completion:(void (^__nullable)(NSString *accessToken, NSString *openID))completion
{
    if (!(kTikTokAppID &&
          kTikTokAppID.length > 0 &&
          code &&
          code.length > 0)) {
        return NO;
    }
    //Wrapper API
    NSString *baseURlstring = [NSString stringWithFormat:@"%@/demoapp/callback/?code=%@&client_key=%@", [self networkDomain], code, kTikTokAppID];
    NSURLSession *session = [NSURLSession sharedSession];

    NSURL *url = [NSURL URLWithString:baseURlstring];
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:url];
    NSURLSessionDataTask *task = [session dataTaskWithRequest:request
                                            completionHandler:^(NSData *_Nullable data,
                                                                NSURLResponse *_Nullable response,
                                                                NSError *_Nullable error) {
        if (data == nil || error) {
            NSLog(@"Fetch AccessToken : NetWorkError");
            return;
        }
        NSString *resultStr = [[NSString alloc]initWithData:data encoding:NSUTF8StringEncoding];
        NSLog(@"Fetch token payload : %@", resultStr);
        NSDictionary *dict = [NSJSONSerialization JSONObjectWithData:data options:0 error:&error];
        if (dict && completion) {
            NSDictionary *dataDict = dict[@"data"];
            if (dataDict) {
                completion(dataDict[@"access_token"], dataDict[@"open_id"]);
            }
        }
    }];
    [task resume];
    return YES;
}

@end
