//
//  OpenPlatformShareDataControl.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//
#import "DemoNetworkManager.h"
#import "OpenPlatformSession.h"
#import "OpenPlatformShareDataControl.h"
#import "UIAlertController+Addition.h"

@interface OpenPlatformShareDataControl ()

@property (nonatomic, strong) TikTokOpenSDKShareRequest *shareReq;
@property (nonatomic, copy, readwrite) NSArray<OpenPlatformSession *> *sessions;
@property (nonatomic, strong) OpenPlatformSession *shareMetaDataSection;

@end

@implementation OpenPlatformShareDataControl

- (instancetype)init
{
    self = [super init];
    if (self) {
        _sessions = @[self.shareMetaDataSection];
        _shareReq = [[TikTokOpenSDKShareRequest alloc] init];
    }

    return self;
}

- (OpenPlatformSession *)shareMetaDataSection
{
    if (!_shareMetaDataSection) {
        _shareMetaDataSection = [[OpenPlatformSession alloc] init];
        _shareMetaDataSection.sessionTitle = @"Share Meta Info";
        _shareMetaDataSection.sessionDesc = @"Share extra info";
        NSMutableArray *metaDataItemArray = [NSMutableArray array];
        OpenPlatformDataItem *item0 = [OpenPlatformDataItem itemForTwoLabelWithTitle:@"Hash Tag"
                                                                          descString:@"Temporarily unavailable"
                                                                             context:nil
                                                                        eventHandler:nil];
        [metaDataItemArray addObject:item0];
        _shareMetaDataSection.items = metaDataItemArray.copy;
    }

    return _shareMetaDataSection;
}

- (void)notifyDataChange;
{
    NSIndexPath *indexPath = [NSIndexPath indexPathForRow:0 inSection:0];
    if (self.dataSourceChange) {
        self.dataSourceChange(indexPath);
    }
}

- (void)shareMediaIds:(NSArray *)media type:(TikTokOpenSDKShareMediaType)type
{
    self.shareReq.localIdentifiers = media;
    self.shareReq.mediaType = type;
    [self.shareReq sendShareRequestWithCompletionBlock:^(TikTokOpenSDKShareResponse *_Nonnull Response) {
        NSString *alertString = nil;
        if (Response.errCode == 0) {
            alertString = [NSString stringWithFormat:@"Share succeed"];
        } else {
            alertString = [NSString stringWithFormat:@"Share failed error code : %@ , error msg : %@", @(Response.errCode), Response.errString];
        }

        [UIAlertController showMsg:alertString inVC:[UIApplication sharedApplication].keyWindow.rootViewController];
    }];
}

@end
