//
//  OpenPlatformDataItem.h
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//

#import <Foundation/Foundation.h>

typedef NS_ENUM(NSInteger, OpenPlatformItemType) {
    OpenPlatformItemTypeNormal,
    OpenPlatformItemTypeTwoLabel,
    OpenPlatformItemTypeEdit,
    OpenPlatformItemTypeTapEdit,
    OpenPlatformItemTypeSwitch,
};

NS_ASSUME_NONNULL_BEGIN

@interface OpenPlatformDataItem : NSObject <NSCopying>

@property (nonatomic, assign) OpenPlatformItemType type;
@property (nonatomic, copy) NSString *titleString;
@property (nonatomic, copy) NSString *context;
@property (nonatomic, assign, getter = isSwitchOn) BOOL switchOn;

@property (nonatomic, copy) void (^eventHandler)(OpenPlatformDataItem *item);

//RightButton
@property (nonatomic, copy) void (^tapRightButtonHandler)(OpenPlatformDataItem *item);
@property (nonatomic, copy) NSString *rightButtonTitle;

//twoLabel
@property (nonatomic, copy) NSString *descString;

//Edit
@property (nonatomic, copy) NSString *placeholder;
@property (nonatomic, copy) NSString *editText;

//Layout
@property (nonatomic, assign, readonly) CGFloat heightForItem;
@property (nonatomic, readonly) NSString *cellIdentify;

+ (instancetype)itemForSwitchWithTitle:(NSString *)title
                               context:(nullable NSString *)context
                       defaultSwitchOn:(BOOL)isDefaultSwitchOn
                          eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler;


+ (instancetype)itemForOneLabelWithTitle:(NSString *)title
                                 context:(nullable NSString *)context
                            eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler;

+ (instancetype)itemForTwoLabelWithTitle:(NSString *)title
                              descString:(nullable NSString *)descString
                                 context:(nullable NSString *)context
                            eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler;

+ (instancetype)itemForEditWithTitle:(NSString *)title
                             context:(nullable NSString *)context
                           placehold:(nullable NSString *)placehold
                        eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler;

+ (instancetype)itemForTwoLabelWithTitle:(NSString *)title
                                subTitle:(NSString *)subTitle
                                 context:(nullable NSString *)context
                               placehold:(nullable NSString *)placehold
                            eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler;

+ (instancetype)itemForEditAndBtnWithTitle:(NSString *)title
                                 placehold:(nullable NSString *)placehold
                                   context:(nullable NSString *)context
                                  btnTitle:(NSString *)btnTitle
                              eventHandler:(nullable void (^)(OpenPlatformDataItem *item))eventHandler
                               tapHandeler:(nullable void (^)(OpenPlatformDataItem *item))tapHandler;

@end

NS_ASSUME_NONNULL_END